from skidl import Pin, Part, SchLib, SKIDL, TEMPLATE

SKIDL_lib_version = '0.0.1'

microchip_dspic33dsc = SchLib(tool=SKIDL).add_parts(*[
        Part(name='DSPIC33FJ128GP204',dest=TEMPLATE,tool=SKIDL,keywords='16-bit Digital Signal Controller Microchip dsPIC',description='40MIPS, 128k Flash, 8k SRAM',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='1',name='SDA1/RP9/CN21/PMD3/RB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='RP22/CN18/PMA1/RC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='RP23/CN17/PMA0/RC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='RP24/CN20/PMA5/RC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='RP25/CN19/PMA6/RC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='7',name='VCAP',func=Pin.PWROUT,do_erc=True),
            Pin(num='8',name='PGED2/EMCD2/RP10/CN16/PMD2/RB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='PGEC2/RP11/CN15/PMD1/RB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='AN12/RP12/CN14/PMD0/RB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='AN1/VREF-/CN3/RA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='OSC1/CLKI/CN30/RA2',do_erc=True),
            Pin(num='40',name='VDD',func=Pin.PWROUT,do_erc=True),
            Pin(num='11',name='AN11/RP13/CN13/PMRD/RB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PGED1/AN2/C2IN-/RP0/CN4/RB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='OSC2/CLKO/CN29/RA3',do_erc=True),
            Pin(num='41',name='PGED3/ASDA1/RP5/CN27/PMD7/RB5',do_erc=True),
            Pin(num='12',name='TMS/PMA10/RA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PGEC1/AN3/C2IN+/RP1/CN5/RB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='TDO/PMA8/RA8',do_erc=True),
            Pin(num='42',name='PGEC3/ASCL1/RP6/CN24/PMD6/RB6',do_erc=True),
            Pin(num='13',name='TCK/PMA7/RA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='AN4/C1IN-/RP2/CN6/RB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='SOSCI/RP4/CN1/RB4',do_erc=True),
            Pin(num='43',name='INT0/RP7/CN23/PMD5/RB7',do_erc=True),
            Pin(num='14',name='AN10/RTCC/RP14/CN12/PMWR/RB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='AN5/C1IN+/RP3/CN7/RB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='SOSCO/T1CK/CN0/RA4',do_erc=True),
            Pin(num='44',name='SCL1/RP8/CN22/PMD4/RB8',do_erc=True),
            Pin(num='15',name='AN9/RP15/CN11/PMCS1/RB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='AN6/RP16/CN8/RC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='TDI/PMA9/RA9',do_erc=True),
            Pin(num='16',name='AVSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='26',name='AN7/RP17/CN9/RC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='RP19/CN28/PMBE/RC3',do_erc=True),
            Pin(num='17',name='AVDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='27',name='AN8/CVREF/RP18/PMA2/CN10/RC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='RP20/CN25/PMA4/RC4',do_erc=True),
            Pin(num='18',name='~MCLR',do_erc=True),
            Pin(num='28',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='38',name='RP21/CN26/PMA3/RC5',do_erc=True),
            Pin(num='19',name='AN0/VREF+/CN2/RA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='VSS',func=Pin.PWROUT,do_erc=True),
            Pin(num='39',name='VSS',func=Pin.PWRIN,do_erc=True)]),
        Part(name='DSPIC33FJ128GP804',dest=TEMPLATE,tool=SKIDL,keywords='16-bit Digital Signal Controller Microchip dsPIC',description='40MIPS, 128k Flash, 16k SRAM, ECAN, Audio DAC',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='1',name='SDA1/RP9/CN21/PMD3/RB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='RP22/CN18/PMA1/RC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='RP23/CN17/PMA0/RC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='RP24/CN20/PMA5/RC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='RP25/CN19/PMA6/RC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='7',name='VCAP',func=Pin.PWROUT,do_erc=True),
            Pin(num='8',name='PGED2/EMCD2/RP10/CN16/PMD2/RB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='PGEC2/RP11/CN15/PMD1/RB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='AN12/DAC1RP/RP12/CN14/PMD0/RB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='AN1/VREF-/CN3/RA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='OSC1/CLKI/CN30/RA2',do_erc=True),
            Pin(num='40',name='VDD',func=Pin.PWROUT,do_erc=True),
            Pin(num='11',name='AN11/DAC1RN/RP13/CN13/PMRD/RB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PGED1/AN2/C2IN-/RP0/CN4/RB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='OSC2/CLKO/CN29/RA3',do_erc=True),
            Pin(num='41',name='PGED3/ASDA1/RP5/CN27/PMD7/RB5',do_erc=True),
            Pin(num='12',name='TMS/PMA10/RA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PGEC1/AN3/C2IN+/RP1/CN5/RB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='TDO/PMA8/RA8',do_erc=True),
            Pin(num='42',name='PGEC3/ASCL1/RP6/CN24/PMD6/RB6',do_erc=True),
            Pin(num='13',name='TCK/PMA7/RA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='AN4/C1IN-/RP2/CN6/RB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='SOSCI/RP4/CN1/RB4',do_erc=True),
            Pin(num='43',name='INT0/RP7/CN23/PMD5/RB7',do_erc=True),
            Pin(num='14',name='AN10/DAC1LP/RTCC/RP14/CN12/PMWR/RB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='AN5/C1IN+/RP3/CN7/RB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='SOSCO/T1CK/CN0/RA4',do_erc=True),
            Pin(num='44',name='SCL1/RP8/CN22/PMD4/RB8',do_erc=True),
            Pin(num='15',name='AN9/DAC1LN/RP15/CN11/PMCS1/RB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='AN6/DAC1RM/RP16/CN8/RC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='TDI/PMA9/RA9',do_erc=True),
            Pin(num='16',name='AVSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='26',name='AN7/DAC1LM/RP17/CN9/RC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='RP19/CN28/PMBE/RC3',do_erc=True),
            Pin(num='17',name='AVDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='27',name='AN8/CVREF/RP18/PMA2/CN10/RC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='RP20/CN25/PMA4/RC4',do_erc=True),
            Pin(num='18',name='~MCLR',do_erc=True),
            Pin(num='28',name='VDD',func=Pin.PWROUT,do_erc=True),
            Pin(num='38',name='RP21/CN26/PMA3/RC5',do_erc=True),
            Pin(num='19',name='AN0/VREF+/CN2/RA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='VSS',do_erc=True),
            Pin(num='39',name='VSS',func=Pin.PWRIN,do_erc=True)]),
        Part(name='DSPIC33FJ128MC204',dest=TEMPLATE,tool=SKIDL,keywords='16-bit Digital Signal Controller Microchip dsPIC Motor Control',description='40MIPS, 128k Flash, 8k SRAM',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='1',name='SDA1/RP9/CN21/PMD3/RB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PWM2H1/RP22/CN18/PMA1/RC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PWM2L1/RP23/CN17/PMA0/RC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='RP24/CN20/PMA5/RC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='RP25/CN19/PMA6/RC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='7',name='VCAP',func=Pin.PWROUT,do_erc=True),
            Pin(num='8',name='PGED2/PWM1H3/RP10/CN16/PMD2/RB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='PGEC2/PWM1L3/RP11/CN15/PMD1/RB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PWM1H2/RP12/CN14/PMD0/RB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='AN1/VREF-/CN3/RA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='OSC1/CLKI/CN30/RA2',do_erc=True),
            Pin(num='40',name='VDD',func=Pin.PWROUT,do_erc=True),
            Pin(num='11',name='PWM1L2/RP13/CN13/PMRD/RB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PGED1/AN2/C2IN-/RP0/CN4/RB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='OSC2/CLKO/CN29/RA3',do_erc=True),
            Pin(num='41',name='PGED3/ASDA1/RP5/CN27/PMD7/RB5',do_erc=True),
            Pin(num='12',name='TMS/PMA10/RA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PGEC1/AN3/C2IN+/RP1/CN5/RB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='TDO/PMA8/RA8',do_erc=True),
            Pin(num='42',name='PGEC3/ASCL1/RP6/CN24/PMD6/RB6',do_erc=True),
            Pin(num='13',name='TCK/PMA7/RA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='AN4/C1IN-/RP2/CN6/RB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='SOSCI/RP4/CN1/RB4',do_erc=True),
            Pin(num='43',name='INT0/RP7/CN23/PMD5/RB7',do_erc=True),
            Pin(num='14',name='PWM1H1/RTCC/RP14/CN12/PMWR/RB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='AN5/C1IN+/RP3/CN7/RB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='SOSCO/T1CK/CN0/RA4',do_erc=True),
            Pin(num='44',name='SCL1/RP8/CN22/PMD4/RB8',do_erc=True),
            Pin(num='15',name='PWM1L/RP15/CN11/PMCS1/RB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='AN6/RP16/CN8/RC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='TDI/PMA9/RA9',do_erc=True),
            Pin(num='16',name='AVSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='26',name='AN7/RP17/CN9/RC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='RP19/CN28/PMBE/RC3',do_erc=True),
            Pin(num='17',name='AVDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='27',name='AN8/CVREF/RP18/PMA2/CN10/RC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='RP20/CN25/PMA4/RC4',do_erc=True),
            Pin(num='18',name='~MCLR',do_erc=True),
            Pin(num='28',name='VDD',func=Pin.PWROUT,do_erc=True),
            Pin(num='38',name='RP21/CN26/PMA3/RC5',do_erc=True),
            Pin(num='19',name='AN0/VREF+/CN2/RA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='VSS',do_erc=True),
            Pin(num='39',name='VSS',func=Pin.PWRIN,do_erc=True)]),
        Part(name='DSPIC33FJ128MC804',dest=TEMPLATE,tool=SKIDL,keywords='16-bit Digital Signal Controller Microchip dsPIC Motor Control',description='40MIPS, 128k Flash, 16k SRAM, ECAN, 16-bit DAC',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='1',name='SDA1/RP9/CN21/PMD3/RB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PWM2H1/RP22/CN18/PMA1/RC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PWM2L1/RP23/CN17/PMA0/RC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='RP24/CN20/PMA5/RC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='RP25/CN19/PMA6/RC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='7',name='VCAP',func=Pin.PWROUT,do_erc=True),
            Pin(num='8',name='PGED2/PWM1H3/RP10/CN16/PMD2/RB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='PGEC2/PWM1L3/RP11/CN15/PMD1/RB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PWM1H2/DAC1RP/RP12/CN14/PMD0/RB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='AN1/VREF-/CN3/RA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='OSC1/CLKI/CN30/RA2',do_erc=True),
            Pin(num='40',name='VDD',func=Pin.PWROUT,do_erc=True),
            Pin(num='11',name='PWM1L2/DAC1RN/RP13/CN13/PMRD/RB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PGED1/AN2/C2IN-/RP0/CN4/RB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='OSC2/CLKO/CN29/RA3',do_erc=True),
            Pin(num='41',name='PGED3/ASDA1/RP5/CN27/PMD7/RB5',do_erc=True),
            Pin(num='12',name='TMS/PMA10/RA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PGEC1/AN3/C2IN+/RP1/CN5/RB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='TDO/PMA8/RA8',do_erc=True),
            Pin(num='42',name='PGEC3/ASCL1/RP6/CN24/PMD6/RB6',do_erc=True),
            Pin(num='13',name='TCK/PMA7/RA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='AN4/C1IN-/RP2/CN6/RB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='SOSCI/RP4/CN1/RB4',do_erc=True),
            Pin(num='43',name='INT0/RP7/CN23/PMD5/RB7',do_erc=True),
            Pin(num='14',name='PWM1H1/DAC1LP/RTCC/RP14/CN12/PMWR/RB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='AN5/C1IN+/RP3/CN7/RB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='SOSCO/T1CK/CN0/RA4',do_erc=True),
            Pin(num='44',name='SCL1/RP8/CN22/PMD4/RB8',do_erc=True),
            Pin(num='15',name='PWM1L/DAC1LN/RP15/CN11/PMCS1/RB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='AN6/DAC1RM/RP16/CN8/RC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='TDI/PMA9/RA9',do_erc=True),
            Pin(num='16',name='AVSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='26',name='AN7/DAC1LM/RP17/CN9/RC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='RP19/CN28/PMBE/RC3',do_erc=True),
            Pin(num='17',name='AVDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='27',name='AN8/CVREF/RP18/PMA2/CN10/RC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='RP20/CN25/PMA4/RC4',do_erc=True),
            Pin(num='18',name='~MCLR',do_erc=True),
            Pin(num='28',name='VDD',func=Pin.PWROUT,do_erc=True),
            Pin(num='38',name='RP21/CN26/PMA3/RC5',do_erc=True),
            Pin(num='19',name='AN0/VREF+/CN2/RA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='VSS',do_erc=True),
            Pin(num='39',name='VSS',func=Pin.PWRIN,do_erc=True)]),
        Part(name='DSPIC33FJ32GP304',dest=TEMPLATE,tool=SKIDL,keywords='16-bit Digital Signal Controller Microchip dsPIC',description='40MIPS, 32k Flash, 4k SRAM',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='1',name='SDA1/RP9/CN21/PMD3/RB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='RP22/CN18/PMA1/RC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='RP23/CN17/PMA0/RC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='RP24/CN20/PMA5/RC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='RP25/CN19/PMA6/RC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='7',name='VCAP',func=Pin.PWROUT,do_erc=True),
            Pin(num='8',name='PGED2/EMCD2/RP10/CN16/PMD2/RB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='PGEC2/RP11/CN15/PMD1/RB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='AN12/RP12/CN14/PMD0/RB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='AN1/VREF-/CN3/RA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='OSC1/CLKI/CN30/RA2',do_erc=True),
            Pin(num='40',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='11',name='AN11/RP13/CN13/PMRD/RB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PGED1/AN2/C2IN-/RP0/CN4/RB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='OSC2/CLKO/CN29/RA3',do_erc=True),
            Pin(num='41',name='PGED3/ASDA1/RP5/CN27/PMD7/RB5',do_erc=True),
            Pin(num='12',name='TMS/PMA10/RA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PGEC1/AN3/C2IN+/RP1/CN5/RB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='TDO/PMA8/RA8',do_erc=True),
            Pin(num='42',name='PGEC3/ASCL1/RP6/CN24/PMD6/RB6',do_erc=True),
            Pin(num='13',name='TCK/PMA7/RA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='AN4/C1IN-/RP2/CN6/RB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='SOSCI/RP4/CN1/RB4',do_erc=True),
            Pin(num='43',name='INT0/RP7/CN23/PMD5/RB7',do_erc=True),
            Pin(num='14',name='AN10/RTCC/RP14/CN12/PMWR/RB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='AN5/C1IN+/RP3/CN7/RB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='SOSCO/T1CK/CN0/RA4',do_erc=True),
            Pin(num='44',name='SCL1/RP8/CN22/PMD4/RB8',do_erc=True),
            Pin(num='15',name='AN9/RP15/CN11/PMCS1/RB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='AN6/RP16/CN8/RC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='TDI/PMA9/RA9',do_erc=True),
            Pin(num='16',name='AVSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='26',name='AN7/RP17/CN9/RC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='RP19/CN28/PMBE/RC3',do_erc=True),
            Pin(num='17',name='AVDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='27',name='AN8/CVREF/RP18/PMA2/CN10/RC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='RP20/CN25/PMA4/RC4',do_erc=True),
            Pin(num='18',name='~MCLR',do_erc=True),
            Pin(num='28',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='38',name='RP21/CN26/PMA3/RC5',do_erc=True),
            Pin(num='19',name='AN0/VREF+/CN2/RA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='39',name='VSS',func=Pin.PWRIN,do_erc=True)]),
        Part(name='DSPIC33FJ32MC304',dest=TEMPLATE,tool=SKIDL,keywords='16-bit Digital Signal Controller Microchip dsPIC Motor Control',description='40MIPS, 32k Flash, 8k SRAM',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='1',name='SDA1/RP9/CN21/PMD3/RB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PWM2H1/RP22/CN18/PMA1/RC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PWM2L1/RP23/CN17/PMA0/RC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='RP24/CN20/PMA5/RC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='RP25/CN19/PMA6/RC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='7',name='VCAP',func=Pin.PWROUT,do_erc=True),
            Pin(num='8',name='PGED2/PWM1H3/RP10/CN16/PMD2/RB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='PGEC2/PWM1L3/RP11/CN15/PMD1/RB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PWM1H2/RP12/CN14/PMD0/RB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='AN1/VREF-/CN3/RA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='OSC1/CLKI/CN30/RA2',do_erc=True),
            Pin(num='40',name='VDD',func=Pin.PWROUT,do_erc=True),
            Pin(num='11',name='PWM1L2/RP13/CN13/PMRD/RB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PGED1/AN2/C2IN-/RP0/CN4/RB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='OSC2/CLKO/CN29/RA3',do_erc=True),
            Pin(num='41',name='PGED3/ASDA1/RP5/CN27/PMD7/RB5',do_erc=True),
            Pin(num='12',name='TMS/PMA10/RA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PGEC1/AN3/C2IN+/RP1/CN5/RB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='TDO/PMA8/RA8',do_erc=True),
            Pin(num='42',name='PGEC3/ASCL1/RP6/CN24/PMD6/RB6',do_erc=True),
            Pin(num='13',name='TCK/PMA7/RA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='AN4/C1IN-/RP2/CN6/RB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='SOSCI/RP4/CN1/RB4',do_erc=True),
            Pin(num='43',name='INT0/RP7/CN23/PMD5/RB7',do_erc=True),
            Pin(num='14',name='PWM1H1/RTCC/RP14/CN12/PMWR/RB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='AN5/C1IN+/RP3/CN7/RB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='SOSCO/T1CK/CN0/RA4',do_erc=True),
            Pin(num='44',name='SCL1/RP8/CN22/PMD4/RB8',do_erc=True),
            Pin(num='15',name='PWM1L/RP15/CN11/PMCS1/RB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='AN6/RP16/CN8/RC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='TDI/PMA9/RA9',do_erc=True),
            Pin(num='16',name='AVSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='26',name='AN7/RP17/CN9/RC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='RP19/CN28/PMBE/RC3',do_erc=True),
            Pin(num='17',name='AVDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='27',name='AN8/CVREF/RP18/PMA2/CN10/RC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='RP20/CN25/PMA4/RC4',do_erc=True),
            Pin(num='18',name='~MCLR',do_erc=True),
            Pin(num='28',name='VDD',func=Pin.PWROUT,do_erc=True),
            Pin(num='38',name='RP21/CN26/PMA3/RC5',do_erc=True),
            Pin(num='19',name='AN0/VREF+/CN2/RA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='VSS',do_erc=True),
            Pin(num='39',name='VSS',func=Pin.PWRIN,do_erc=True)]),
        Part(name='DSPIC33FJ64GP204',dest=TEMPLATE,tool=SKIDL,keywords='16-bit Digital Signal Controller Microchip dsPIC',description='40MIPS, 64k Flash, 8k SRAM',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='1',name='SDA1/RP9/CN21/PMD3/RB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='RP22/CN18/PMA1/RC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='RP23/CN17/PMA0/RC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='RP24/CN20/PMA5/RC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='RP25/CN19/PMA6/RC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='7',name='VCAP',func=Pin.PWROUT,do_erc=True),
            Pin(num='8',name='PGED2/EMCD2/RP10/CN16/PMD2/RB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='PGEC2/RP11/CN15/PMD1/RB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='AN12/RP12/CN14/PMD0/RB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='AN1/VREF-/CN3/RA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='OSC1/CLKI/CN30/RA2',do_erc=True),
            Pin(num='40',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='11',name='AN11/RP13/CN13/PMRD/RB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PGED1/AN2/C2IN-/RP0/CN4/RB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='OSC2/CLKO/CN29/RA3',do_erc=True),
            Pin(num='41',name='PGED3/ASDA1/RP5/CN27/PMD7/RB5',do_erc=True),
            Pin(num='12',name='TMS/PMA10/RA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PGEC1/AN3/C2IN+/RP1/CN5/RB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='TDO/PMA8/RA8',do_erc=True),
            Pin(num='42',name='PGEC3/ASCL1/RP6/CN24/PMD6/RB6',do_erc=True),
            Pin(num='13',name='TCK/PMA7/RA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='AN4/C1IN-/RP2/CN6/RB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='SOSCI/RP4/CN1/RB4',do_erc=True),
            Pin(num='43',name='INT0/RP7/CN23/PMD5/RB7',do_erc=True),
            Pin(num='14',name='AN10/RTCC/RP14/CN12/PMWR/RB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='AN5/C1IN+/RP3/CN7/RB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='SOSCO/T1CK/CN0/RA4',do_erc=True),
            Pin(num='44',name='SCL1/RP8/CN22/PMD4/RB8',do_erc=True),
            Pin(num='15',name='AN9/RP15/CN11/PMCS1/RB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='AN6/RP16/CN8/RC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='TDI/PMA9/RA9',do_erc=True),
            Pin(num='16',name='AVSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='26',name='AN7/RP17/CN9/RC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='RP19/CN28/PMBE/RC3',do_erc=True),
            Pin(num='17',name='AVDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='27',name='AN8/CVREF/RP18/PMA2/CN10/RC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='RP20/CN25/PMA4/RC4',do_erc=True),
            Pin(num='18',name='~MCLR',do_erc=True),
            Pin(num='28',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='38',name='RP21/CN26/PMA3/RC5',do_erc=True),
            Pin(num='19',name='AN0/VREF+/CN2/RA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='39',name='VSS',func=Pin.PWRIN,do_erc=True)]),
        Part(name='DSPIC33FJ64GP804',dest=TEMPLATE,tool=SKIDL,keywords='16-bit Digital Signal Controller Microchip dsPIC33',description='40MIPS, 64k Flash, 16k SRAM, ECAN, Audio DAC',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='1',name='SDA1/RP9/CN21/PMD3/RB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='RP22/CN18/PMA1/RC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='RP23/CN17/PMA0/RC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='RP24/CN20/PMA5/RC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='RP25/CN19/PMA6/RC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='7',name='VCAP',func=Pin.PWROUT,do_erc=True),
            Pin(num='8',name='PGED2/EMCD2/RP10/CN16/PMD2/RB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='PGEC2/RP11/CN15/PMD1/RB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='AN12/DAC1RP/RP12/CN14/PMD0/RB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='AN1/VREF-/CN3/RA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='OSC1/CLKI/CN30/RA2',do_erc=True),
            Pin(num='40',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='11',name='AN11/DAC1RN/RP13/CN13/PMRD/RB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PGED1/AN2/C2IN-/RP0/CN4/RB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='OSC2/CLKO/CN29/RA3',do_erc=True),
            Pin(num='41',name='PGED3/ASDA1/RP5/CN27/PMD7/RB5',do_erc=True),
            Pin(num='12',name='TMS/PMA10/RA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PGEC1/AN3/C2IN+/RP1/CN5/RB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='TDO/PMA8/RA8',do_erc=True),
            Pin(num='42',name='PGEC3/ASCL1/RP6/CN24/PMD6/RB6',do_erc=True),
            Pin(num='13',name='TCK/PMA7/RA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='AN4/C1IN-/RP2/CN6/RB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='SOSCI/RP4/CN1/RB4',do_erc=True),
            Pin(num='43',name='INT0/RP7/CN23/PMD5/RB7',do_erc=True),
            Pin(num='14',name='AN10/DAC1LP/RTCC/RP14/CN12/PMWR/RB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='AN5/C1IN+/RP3/CN7/RB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='SOSCO/T1CK/CN0/RA4',do_erc=True),
            Pin(num='44',name='SCL1/RP8/CN22/PMD4/RB8',do_erc=True),
            Pin(num='15',name='AN9/DAC1LN/RP15/CN11/PMCS1/RB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='AN6/DAC1RM/RP16/CN8/RC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='TDI/PMA9/RA9',do_erc=True),
            Pin(num='16',name='AVSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='26',name='AN7/DAC1LM/RP17/CN9/RC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='RP19/CN28/PMBE/RC3',do_erc=True),
            Pin(num='17',name='AVDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='27',name='AN8/CVREF/RP18/PMA2/CN10/RC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='RP20/CN25/PMA4/RC4',do_erc=True),
            Pin(num='18',name='~MCLR',do_erc=True),
            Pin(num='28',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='38',name='RP21/CN26/PMA3/RC5',do_erc=True),
            Pin(num='19',name='AN0/VREF+/CN2/RA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='39',name='VSS',func=Pin.PWRIN,do_erc=True)]),
        Part(name='DSPIC33FJ64MC204',dest=TEMPLATE,tool=SKIDL,keywords='16-bit Digital Signal Controller Microchip dsPIC Motor Control',description='40MIPS, 64k Flash, 8k SRAM',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='1',name='SDA1/RP9/CN21/PMD3/RB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PWM2H1/RP22/CN18/PMA1/RC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PWM2L1/RP23/CN17/PMA0/RC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='RP24/CN20/PMA5/RC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='RP25/CN19/PMA6/RC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='7',name='VCAP',func=Pin.PWROUT,do_erc=True),
            Pin(num='8',name='PGED2/PWM1H3/RP10/CN16/PMD2/RB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='PGEC2/PWM1L3/RP11/CN15/PMD1/RB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PWM1H2/RP12/CN14/PMD0/RB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='AN1/VREF-/CN3/RA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='OSC1/CLKI/CN30/RA2',do_erc=True),
            Pin(num='40',name='VDD',func=Pin.PWROUT,do_erc=True),
            Pin(num='11',name='PWM1L2/RP13/CN13/PMRD/RB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PGED1/AN2/C2IN-/RP0/CN4/RB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='OSC2/CLKO/CN29/RA3',do_erc=True),
            Pin(num='41',name='PGED3/ASDA1/RP5/CN27/PMD7/RB5',do_erc=True),
            Pin(num='12',name='TMS/PMA10/RA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PGEC1/AN3/C2IN+/RP1/CN5/RB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='TDO/PMA8/RA8',do_erc=True),
            Pin(num='42',name='PGEC3/ASCL1/RP6/CN24/PMD6/RB6',do_erc=True),
            Pin(num='13',name='TCK/PMA7/RA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='AN4/C1IN-/RP2/CN6/RB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='SOSCI/RP4/CN1/RB4',do_erc=True),
            Pin(num='43',name='INT0/RP7/CN23/PMD5/RB7',do_erc=True),
            Pin(num='14',name='PWM1H1/RTCC/RP14/CN12/PMWR/RB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='AN5/C1IN+/RP3/CN7/RB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='SOSCO/T1CK/CN0/RA4',do_erc=True),
            Pin(num='44',name='SCL1/RP8/CN22/PMD4/RB8',do_erc=True),
            Pin(num='15',name='PWM1L/RP15/CN11/PMCS1/RB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='AN6/RP16/CN8/RC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='TDI/PMA9/RA9',do_erc=True),
            Pin(num='16',name='AVSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='26',name='AN7/RP17/CN9/RC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='RP19/CN28/PMBE/RC3',do_erc=True),
            Pin(num='17',name='AVDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='27',name='AN8/CVREF/RP18/PMA2/CN10/RC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='RP20/CN25/PMA4/RC4',do_erc=True),
            Pin(num='18',name='~MCLR',do_erc=True),
            Pin(num='28',name='VDD',func=Pin.PWROUT,do_erc=True),
            Pin(num='38',name='RP21/CN26/PMA3/RC5',do_erc=True),
            Pin(num='19',name='AN0/VREF+/CN2/RA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='VSS',do_erc=True),
            Pin(num='39',name='VSS',func=Pin.PWRIN,do_erc=True)]),
        Part(name='DSPIC33FJ64MC804',dest=TEMPLATE,tool=SKIDL,keywords='16-bit Digital Signal Controller Microchip dsPIC Motor Control',description='40MIPS, 64k Flash, 16k SRAM, ECAN, 16-bit DAC',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='1',name='SDA1/RP9/CN21/PMD3/RB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PWM2H1/RP22/CN18/PMA1/RC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PWM2L1/RP23/CN17/PMA0/RC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='RP24/CN20/PMA5/RC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='RP25/CN19/PMA6/RC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='7',name='VCAP',func=Pin.PWROUT,do_erc=True),
            Pin(num='8',name='PGED2/PWM1H3/RP10/CN16/PMD2/RB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='PGEC2/PWM1L3/RP11/CN15/PMD1/RB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PWM1H2/DAC1RP/RP12/CN14/PMD0/RB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='AN1/VREF-/CN3/RA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='OSC1/CLKI/CN30/RA2',do_erc=True),
            Pin(num='40',name='VDD',func=Pin.PWROUT,do_erc=True),
            Pin(num='11',name='PWM1L2/DAC1RN/RP13/CN13/PMRD/RB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PGED1/AN2/C2IN-/RP0/CN4/RB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='OSC2/CLKO/CN29/RA3',do_erc=True),
            Pin(num='41',name='PGED3/ASDA1/RP5/CN27/PMD7/RB5',do_erc=True),
            Pin(num='12',name='TMS/PMA10/RA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PGEC1/AN3/C2IN+/RP1/CN5/RB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='TDO/PMA8/RA8',do_erc=True),
            Pin(num='42',name='PGEC3/ASCL1/RP6/CN24/PMD6/RB6',do_erc=True),
            Pin(num='13',name='TCK/PMA7/RA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='AN4/C1IN-/RP2/CN6/RB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='SOSCI/RP4/CN1/RB4',do_erc=True),
            Pin(num='43',name='INT0/RP7/CN23/PMD5/RB7',do_erc=True),
            Pin(num='14',name='PWM1H1/DAC1LP/RTCC/RP14/CN12/PMWR/RB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='AN5/C1IN+/RP3/CN7/RB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='SOSCO/T1CK/CN0/RA4',do_erc=True),
            Pin(num='44',name='SCL1/RP8/CN22/PMD4/RB8',do_erc=True),
            Pin(num='15',name='PWM1L/DAC1LN/RP15/CN11/PMCS1/RB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='AN6/DAC1RM/RP16/CN8/RC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='TDI/PMA9/RA9',do_erc=True),
            Pin(num='16',name='AVSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='26',name='AN7/DAC1LM/RP17/CN9/RC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='RP19/CN28/PMBE/RC3',do_erc=True),
            Pin(num='17',name='AVDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='27',name='AN8/CVREF/RP18/PMA2/CN10/RC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='RP20/CN25/PMA4/RC4',do_erc=True),
            Pin(num='18',name='~MCLR',do_erc=True),
            Pin(num='28',name='VDD',func=Pin.PWROUT,do_erc=True),
            Pin(num='38',name='RP21/CN26/PMA3/RC5',do_erc=True),
            Pin(num='19',name='AN0/VREF+/CN2/RA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='VSS',do_erc=True),
            Pin(num='39',name='VSS',func=Pin.PWRIN,do_erc=True)])])


from skidl import Pin, Part, SchLib, SKIDL, TEMPLATE

SKIDL_lib_version = '0.0.1'

RFSolutions = SchLib(tool=SKIDL).add_parts(*[
        Part(name='ZETA-433-SO',dest=TEMPLATE,tool=SKIDL,keywords='RF TRANSCEIVER MODULE',description='FM ZETA TRANSCEIVER MODULE, OPTIMISED FOR 433MHZ',ref_prefix='U',num_units=1,do_erc=True,aliases=['ZETA-868-SO', 'ZETA-915-SO'],pins=[
            Pin(num='1',name='ANT',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='3',name='SDN',do_erc=True),
            Pin(num='4',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='IRQ',func=Pin.OUTPUT,do_erc=True),
            Pin(num='6',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='7',name='GPIO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='GPIO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='SCLK',do_erc=True),
            Pin(num='10',name='SDI',do_erc=True),
            Pin(num='11',name='SDO',do_erc=True),
            Pin(num='12',name='SEL',do_erc=True)])])


from skidl import Pin, Part, SchLib, SKIDL, TEMPLATE

SKIDL_lib_version = '0.0.1'

Altera = SchLib(tool=SKIDL).add_parts(*[
        Part(name='EP1210',dest=TEMPLATE,tool=SKIDL,keywords='EPLD',description='EPLD',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='1',name='CLK1',do_erc=True),
            Pin(num='2',name='I0',do_erc=True),
            Pin(num='3',name='I1',do_erc=True),
            Pin(num='4',name='I2',do_erc=True),
            Pin(num='5',name='I3',do_erc=True),
            Pin(num='6',name='I4',do_erc=True),
            Pin(num='7',name='I5',do_erc=True),
            Pin(num='8',name='B10',do_erc=True),
            Pin(num='9',name='B11',do_erc=True),
            Pin(num='10',name='B12',do_erc=True),
            Pin(num='20',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='30',name='A12',do_erc=True),
            Pin(num='40',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='11',name='B13',do_erc=True),
            Pin(num='21',name='A33',do_erc=True),
            Pin(num='31',name='A11',do_erc=True),
            Pin(num='12',name='B20',do_erc=True),
            Pin(num='22',name='A32',do_erc=True),
            Pin(num='32',name='A10',do_erc=True),
            Pin(num='13',name='B21',do_erc=True),
            Pin(num='23',name='A31',do_erc=True),
            Pin(num='33',name='I11',do_erc=True),
            Pin(num='14',name='B22',do_erc=True),
            Pin(num='24',name='A30',do_erc=True),
            Pin(num='34',name='I10',do_erc=True),
            Pin(num='15',name='B23',do_erc=True),
            Pin(num='25',name='A23',do_erc=True),
            Pin(num='35',name='I9',do_erc=True),
            Pin(num='16',name='B30',do_erc=True),
            Pin(num='26',name='A22',do_erc=True),
            Pin(num='36',name='I8',do_erc=True),
            Pin(num='17',name='B31',do_erc=True),
            Pin(num='27',name='A21',do_erc=True),
            Pin(num='37',name='I7',do_erc=True),
            Pin(num='18',name='B32',do_erc=True),
            Pin(num='28',name='A20',do_erc=True),
            Pin(num='38',name='I6',do_erc=True),
            Pin(num='19',name='B33',do_erc=True),
            Pin(num='29',name='A13',do_erc=True),
            Pin(num='39',name='VCC',func=Pin.PWRIN,do_erc=True)]),
        Part(name='EP1810',dest=TEMPLATE,tool=SKIDL,keywords='EPLD',description='EPLD',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='1',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='2',name='I/O_1A',do_erc=True),
            Pin(num='3',name='I/O_2A',do_erc=True),
            Pin(num='4',name='I/O_3A',do_erc=True),
            Pin(num='5',name='I/O_4A',do_erc=True),
            Pin(num='6',name='I/O_5A',do_erc=True),
            Pin(num='7',name='I/O_6A',do_erc=True),
            Pin(num='8',name='I/O_7A',do_erc=True),
            Pin(num='9',name='I/O_8A',do_erc=True),
            Pin(num='10',name='I/O_9A',do_erc=True),
            Pin(num='20',name='INP6',do_erc=True),
            Pin(num='30',name='I/O_20B',do_erc=True),
            Pin(num='40',name='I/O_29C',do_erc=True),
            Pin(num='50',name='INP11',do_erc=True),
            Pin(num='60',name='I/O_40D',do_erc=True),
            Pin(num='11',name='I/O_10A',do_erc=True),
            Pin(num='21',name='INP7',do_erc=True),
            Pin(num='31',name='I/O_21B',do_erc=True),
            Pin(num='41',name='I/O_30C',do_erc=True),
            Pin(num='51',name='CLK3/INP12',do_erc=True),
            Pin(num='61',name='I/O_41D',do_erc=True),
            Pin(num='12',name='I/O_11A',do_erc=True),
            Pin(num='22',name='INP8',do_erc=True),
            Pin(num='32',name='I/O_22B',do_erc=True),
            Pin(num='42',name='I/O_31C',do_erc=True),
            Pin(num='52',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='62',name='I/O_42D',do_erc=True),
            Pin(num='13',name='I/O_12A',do_erc=True),
            Pin(num='23',name='I/O_13B',do_erc=True),
            Pin(num='33',name='I/O_23B',do_erc=True),
            Pin(num='43',name='I/O_32C',do_erc=True),
            Pin(num='53',name='CLK4/INP13',do_erc=True),
            Pin(num='63',name='I/O_43D',do_erc=True),
            Pin(num='14',name='INP1',do_erc=True),
            Pin(num='24',name='I/O_14B',do_erc=True),
            Pin(num='34',name='I/O_24B',do_erc=True),
            Pin(num='44',name='I/O_33C',do_erc=True),
            Pin(num='54',name='INP14',do_erc=True),
            Pin(num='64',name='I/O_44D',do_erc=True),
            Pin(num='15',name='INP2',do_erc=True),
            Pin(num='25',name='I/O_15B',do_erc=True),
            Pin(num='35',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='45',name='I/O_34C',do_erc=True),
            Pin(num='55',name='INP15',do_erc=True),
            Pin(num='65',name='I/O_45D',do_erc=True),
            Pin(num='16',name='INP3',do_erc=True),
            Pin(num='26',name='I/O_16B',do_erc=True),
            Pin(num='36',name='I/O_25C',do_erc=True),
            Pin(num='46',name='I/O_35C',do_erc=True),
            Pin(num='56',name='INP16',do_erc=True),
            Pin(num='66',name='I/O_46D',do_erc=True),
            Pin(num='17',name='INP4/CLK1',do_erc=True),
            Pin(num='27',name='I/O_17B',do_erc=True),
            Pin(num='37',name='I/O_26C',do_erc=True),
            Pin(num='47',name='I/O_36C',do_erc=True),
            Pin(num='57',name='I/O_37D',do_erc=True),
            Pin(num='67',name='I/O_47D',do_erc=True),
            Pin(num='18',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='28',name='I/O_18B',do_erc=True),
            Pin(num='38',name='I/O_27C',do_erc=True),
            Pin(num='48',name='INP9',do_erc=True),
            Pin(num='58',name='I/O_38D',do_erc=True),
            Pin(num='68',name='I/O_48D',do_erc=True),
            Pin(num='19',name='INP5/CLK2',do_erc=True),
            Pin(num='29',name='I/O_19B',do_erc=True),
            Pin(num='39',name='I/O_28C',do_erc=True),
            Pin(num='49',name='INP10',do_erc=True),
            Pin(num='59',name='I/O_39D',do_erc=True)]),
        Part(name='EP300',dest=TEMPLATE,tool=SKIDL,keywords='EPLD',description='EPLD, 8 Macrocell, DIP-20',ref_prefix='U',num_units=1,fplist=['DIP*W7.62mm*'],do_erc=True,aliases=['EP310'],pins=[
            Pin(num='1',name='CLK',do_erc=True),
            Pin(num='2',name='IN1',do_erc=True),
            Pin(num='3',name='IN2',do_erc=True),
            Pin(num='4',name='IN3',do_erc=True),
            Pin(num='5',name='IN4',do_erc=True),
            Pin(num='6',name='IN5',do_erc=True),
            Pin(num='7',name='IN6',do_erc=True),
            Pin(num='8',name='IN7',do_erc=True),
            Pin(num='9',name='IN9',do_erc=True),
            Pin(num='10',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='20',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='11',name='IN10',do_erc=True),
            Pin(num='12',name='IO1',do_erc=True),
            Pin(num='13',name='IO2',do_erc=True),
            Pin(num='14',name='IO3',do_erc=True),
            Pin(num='15',name='IO4',do_erc=True),
            Pin(num='16',name='IO5',do_erc=True),
            Pin(num='17',name='IO6',do_erc=True),
            Pin(num='18',name='IO7',do_erc=True),
            Pin(num='19',name='IO8',do_erc=True)]),
        Part(name='EP320',dest=TEMPLATE,tool=SKIDL,keywords='EPLD',description='EPLD',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='1',name='CK/IN',do_erc=True),
            Pin(num='2',name='IN2',do_erc=True),
            Pin(num='3',name='IN3',do_erc=True),
            Pin(num='4',name='IN4',do_erc=True),
            Pin(num='5',name='IN5',do_erc=True),
            Pin(num='6',name='IN6',do_erc=True),
            Pin(num='7',name='IN7',do_erc=True),
            Pin(num='8',name='IN8',do_erc=True),
            Pin(num='9',name='IN9',do_erc=True),
            Pin(num='10',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='20',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='11',name='I/O11',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='I/O12',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='I/O13',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='I/O14',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='I/O15',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='I/O16',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='I/O17',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='I/O18',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='I/O19',func=Pin.BIDIR,do_erc=True)]),
        Part(name='EP600',dest=TEMPLATE,tool=SKIDL,keywords='EPLD',description='EPLD',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='1',name='CLK1',do_erc=True),
            Pin(num='2',name='IN2',do_erc=True),
            Pin(num='3',name='I/O3',func=Pin.PASSIVE,do_erc=True),
            Pin(num='4',name='I/O4',func=Pin.PASSIVE,do_erc=True),
            Pin(num='5',name='I/O5',func=Pin.PASSIVE,do_erc=True),
            Pin(num='6',name='I/O6',func=Pin.PASSIVE,do_erc=True),
            Pin(num='7',name='I/O7',func=Pin.PASSIVE,do_erc=True),
            Pin(num='8',name='I/O8',func=Pin.PASSIVE,do_erc=True),
            Pin(num='9',name='I/O9',func=Pin.PASSIVE,do_erc=True),
            Pin(num='10',name='I/O10',func=Pin.PASSIVE,do_erc=True),
            Pin(num='20',name='I/O20',func=Pin.PASSIVE,do_erc=True),
            Pin(num='11',name='IN11',do_erc=True),
            Pin(num='21',name='I/O21',func=Pin.PASSIVE,do_erc=True),
            Pin(num='12',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='22',name='I/O22',func=Pin.PASSIVE,do_erc=True),
            Pin(num='13',name='CLK2',do_erc=True),
            Pin(num='23',name='IN23',do_erc=True),
            Pin(num='14',name='IN14',do_erc=True),
            Pin(num='24',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='15',name='I/O15',func=Pin.PASSIVE,do_erc=True),
            Pin(num='16',name='I/O16',func=Pin.PASSIVE,do_erc=True),
            Pin(num='17',name='I/O17',func=Pin.PASSIVE,do_erc=True),
            Pin(num='18',name='I/O18',func=Pin.PASSIVE,do_erc=True),
            Pin(num='19',name='I/O19',func=Pin.PASSIVE,do_erc=True)]),
        Part(name='EP910',dest=TEMPLATE,tool=SKIDL,keywords='EPLD',description='EPLD',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='1',name='CLK1',do_erc=True),
            Pin(num='2',name='I0',do_erc=True),
            Pin(num='3',name='I1',do_erc=True),
            Pin(num='4',name='I2',do_erc=True),
            Pin(num='5',name='IO0',do_erc=True),
            Pin(num='6',name='IO1',do_erc=True),
            Pin(num='7',name='IO2',do_erc=True),
            Pin(num='8',name='IO3',do_erc=True),
            Pin(num='9',name='IO4',do_erc=True),
            Pin(num='10',name='IO5',do_erc=True),
            Pin(num='20',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='30',name='IO18',do_erc=True),
            Pin(num='40',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='11',name='IO6',do_erc=True),
            Pin(num='21',name='CLK2',do_erc=True),
            Pin(num='31',name='IO17',do_erc=True),
            Pin(num='12',name='IO7',do_erc=True),
            Pin(num='22',name='I11',do_erc=True),
            Pin(num='32',name='IO16',do_erc=True),
            Pin(num='13',name='IO8',do_erc=True),
            Pin(num='23',name='I10',do_erc=True),
            Pin(num='33',name='IO15',do_erc=True),
            Pin(num='14',name='IO9',do_erc=True),
            Pin(num='24',name='I9',do_erc=True),
            Pin(num='34',name='IO14',do_erc=True),
            Pin(num='15',name='IO10',do_erc=True),
            Pin(num='25',name='IO23',do_erc=True),
            Pin(num='35',name='IO13',do_erc=True),
            Pin(num='16',name='IO11',do_erc=True),
            Pin(num='26',name='IO22',do_erc=True),
            Pin(num='36',name='IO12',do_erc=True),
            Pin(num='17',name='I3',do_erc=True),
            Pin(num='27',name='IO21',do_erc=True),
            Pin(num='37',name='I8',do_erc=True),
            Pin(num='18',name='I4',do_erc=True),
            Pin(num='28',name='IO20',do_erc=True),
            Pin(num='38',name='I7',do_erc=True),
            Pin(num='19',name='I5',do_erc=True),
            Pin(num='29',name='IO19',do_erc=True),
            Pin(num='39',name='I6',do_erc=True)])])


from skidl import Pin, Part, SchLib, SKIDL, TEMPLATE

SKIDL_lib_version = '0.0.1'

allegro = SchLib(tool=SKIDL).add_parts(*[
        Part(name='ACS706ELC-05C',dest=TEMPLATE,tool=SKIDL,keywords='hall effect current monitor sensor isolated obsolete',description='15A, Hall Effect Linear Current Sensor, SO-8, OBSOLETE',ref_prefix='U',num_units=1,fplist=['SOIC*3.9x4.9mm*Pitch1.27mm*'],do_erc=True,pins=[
            Pin(num='1',name='IP+',func=Pin.PASSIVE,do_erc=True),
            Pin(num='2',name='IP+',func=Pin.PASSIVE,do_erc=True),
            Pin(num='3',name='IP-',func=Pin.PASSIVE,do_erc=True),
            Pin(num='4',name='IP-',func=Pin.PASSIVE,do_erc=True),
            Pin(num='5',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='6',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='7',name='VIout',func=Pin.OUTPUT,do_erc=True),
            Pin(num='8',name='VCC',func=Pin.PWRIN,do_erc=True)]),
        Part(name='ACS711xLCTR-12AB',dest=TEMPLATE,tool=SKIDL,keywords='hall effect current monitor sensor isolated',description='±25A, Bidirectional, hall-effect current sensor, +3.3V supply, 55mV/A, SO-8',ref_prefix='U',num_units=1,fplist=['SOIC*3.9x4.9mm*Pitch1.27mm*'],do_erc=True,aliases=['ACS711xLCTR-25AB'],pins=[
            Pin(num='1',name='IP+',func=Pin.PASSIVE,do_erc=True),
            Pin(num='2',name='IP+',func=Pin.PASSIVE,do_erc=True),
            Pin(num='3',name='IP-',func=Pin.PASSIVE,do_erc=True),
            Pin(num='4',name='IP-',func=Pin.PASSIVE,do_erc=True),
            Pin(num='5',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='6',name='~FAULT',func=Pin.OUTPUT,do_erc=True),
            Pin(num='7',name='VIout',func=Pin.OUTPUT,do_erc=True),
            Pin(num='8',name='VCC',func=Pin.PWRIN,do_erc=True)]),
        Part(name='ACS712ELCTR-05B-T',dest=TEMPLATE,tool=SKIDL,keywords='hall effect current monitor sensor isolated',description='30A Unidirectional hall-effect current sensor, +5.0V supply, 133mV/A, SO-8',ref_prefix='U',num_units=1,fplist=['SOIC*3.9x4.9m*Pitch1.27mm*'],do_erc=True,aliases=['ACS712ELCTR-20A-T', 'ACS712ELCTR-30A-T', 'ACS713ELCTR-20A-T', 'ACS713ELCTR-30A-T'],pins=[
            Pin(num='1',name='IP+',func=Pin.PASSIVE,do_erc=True),
            Pin(num='2',name='IP+',func=Pin.PASSIVE,do_erc=True),
            Pin(num='3',name='IP-',func=Pin.PASSIVE,do_erc=True),
            Pin(num='4',name='IP-',func=Pin.PASSIVE,do_erc=True),
            Pin(num='5',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='6',name='Filter',func=Pin.PASSIVE,do_erc=True),
            Pin(num='7',name='VIout',func=Pin.OUTPUT,do_erc=True),
            Pin(num='8',name='VCC',func=Pin.PWRIN,do_erc=True)]),
        Part(name='ACS722LLCTR-05AB-T',dest=TEMPLATE,tool=SKIDL,keywords='hall effect current monitor sensor isolated',description='40A Unidirectional hall-effect current sensor, +3.3V supply, 66mV/A, SO-8',ref_prefix='U',num_units=1,fplist=['SOIC*3.9x4.9mm*Pitch1.27mm*'],do_erc=True,aliases=['ACS722LLCTR-10AU-T', 'ACS722LLCTR-10AB-T', 'ACS722LLCTR-20AU-T', 'ACS722LLCTR-20AB-T', 'ACS722LLCTR-40AU-T', 'ACS722LLCTR-40AB-T'],pins=[
            Pin(num='1',name='IP+',func=Pin.PASSIVE,do_erc=True),
            Pin(num='2',name='IP+',func=Pin.PASSIVE,do_erc=True),
            Pin(num='3',name='IP-',func=Pin.PASSIVE,do_erc=True),
            Pin(num='4',name='IP-',func=Pin.PASSIVE,do_erc=True),
            Pin(num='5',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='6',name='BWSel',do_erc=True),
            Pin(num='7',name='VIout',func=Pin.OUTPUT,do_erc=True),
            Pin(num='8',name='VCC',func=Pin.PWRIN,do_erc=True)]),
        Part(name='ACS756SCB-050B',dest=TEMPLATE,tool=SKIDL,keywords='hall effect current monitor sensor isolated',description='±100A Bidirectional hall-effect current sensor, +3.3V supply, 13.2mV/A, CB-5 leadform',ref_prefix='U',num_units=1,do_erc=True,aliases=['ACS756SCB-100B', 'ACS758LCB-050B', 'ACS758LCB-050U', 'ACS758LCB-100B', 'ACS758LCB-100U', 'ACS758KCB-150B', 'ACS758KCB-150U', 'ACS758ECB-200B', 'ACS758ECB-200U', 'ACS759LCB-050B', 'ACS759LCB-100B', 'ACS759KCB-150B', 'ACS759ECB-200B'],pins=[
            Pin(num='1',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='2',name='GND',func=Pin.PWRIN,do_erc=True),
            Pin(num='3',name='OUT',func=Pin.OUTPUT,do_erc=True),
            Pin(num='4',name='IP+',func=Pin.PASSIVE,do_erc=True),
            Pin(num='5',name='IP-',func=Pin.PASSIVE,do_erc=True)])])


from skidl import Pin, Part, SchLib, SKIDL, TEMPLATE

SKIDL_lib_version = '0.0.1'

Worldsemi = SchLib(tool=SKIDL).add_parts(*[
        Part(name='WS2812B',dest=TEMPLATE,tool=SKIDL,keywords='RGB LED NeoPixel',description='RGB LED with integrated controller',ref_prefix='LED',num_units=1,do_erc=True,pins=[
            Pin(num='1',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='2',name='DOUT',func=Pin.OUTPUT,do_erc=True),
            Pin(num='3',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='4',name='DIN',do_erc=True)]),
        Part(name='WS2812S',dest=TEMPLATE,tool=SKIDL,keywords='RGB LED',description='RGB LED with integrated controller',ref_prefix='LED',num_units=1,do_erc=True,aliases=['WS2812'],pins=[
            Pin(num='1',name='DOUT',func=Pin.OUTPUT,do_erc=True),
            Pin(num='2',name='DIN',do_erc=True),
            Pin(num='3',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='6',name='VSS',func=Pin.PWRIN,do_erc=True)]),
        Part(name='WS2822S_A',dest=TEMPLATE,tool=SKIDL,keywords='RGB LED',description='RGB LED with integrated controller',ref_prefix='LED',num_units=1,do_erc=True,pins=[
            Pin(num='1',name='DIN',do_erc=True),
            Pin(num='2',name='ADRIN',do_erc=True),
            Pin(num='3',name='VCC',func=Pin.PWRIN,do_erc=True),
            Pin(num='4',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='ADROUT',func=Pin.OUTPUT,do_erc=True),
            Pin(num='6',name='VDD',func=Pin.PWRIN,do_erc=True)]),
        Part(name='WS2822S_B',dest=TEMPLATE,tool=SKIDL,keywords='RGB LED',description='RGB LED with integrated controller',ref_prefix='LED',num_units=1,do_erc=True,pins=[
            Pin(num='1',name='ADROUT',func=Pin.OUTPUT,do_erc=True),
            Pin(num='2',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='3',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='4',name='DIN',do_erc=True),
            Pin(num='5',name='ADRIN',do_erc=True),
            Pin(num='6',name='VCC',func=Pin.PWRIN,do_erc=True)])])


import pytest

# Skip this test module if PySpice is missing.
pexpect = pytest.importorskip("PySpice")

from skidl.pyspice import *
from .setup_teardown import *
import PySpice


def test_lib_import_1():
    lib_search_paths[SPICE].append('C:\Program Files (x86)\LTC\LTspiceIV\lib')
    lib = SchLib('lt1083', tool=SPICE)
    assert len(lib) > 0
    for p in lib.get_parts():
        print(p)

def test_lib_import_2():
    with pytest.raises(Exception):
        lib = SchLib('lt1074', tool=SPICE)

def test_lib_export_1():
    set_default_tool(SPICE)
    lib = SchLib('lt1083', tool=SPICE)
    lib.export('my_lt1083', tool=SKIDL)
    my_lib = SchLib('my_lt1083', tool=SKIDL)
    assert len(lib) == len(my_lib)



# -*- coding: utf-8 -*-

# MIT license
#
# Copyright (C) 2018 by XESS Corp.
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.

"""
Installs handlers for various EDA tools.
"""

import os
import os.path
from .. import SchLib
from .. import Circuit
from .. import Part
from .. import Net

lib_suffixes = {}

# The ECAD tool directories will be found in this directory.
directory = os.path.dirname(__file__)

# Search for the EDA tool modules and import them.
for module in os.listdir(directory):

    # Avoid directories like __pycache__.
    if module.startswith('__'):
        continue

    module_name, module_ext = os.path.splitext(os.path.basename(module))

    # Don't import anything but Python files.
    if module_ext not in ('.py',):
        continue

    # Import the module.
    mod = __import__(module_name, globals(), locals(), [], level=1)

    # Get some info from the imported module.
    tool_name = getattr(mod, 'tool_name')
    lib_suffix = getattr(mod, 'lib_suffix')

    # Store library file suffix for this tool.
    lib_suffixes[tool_name] = lib_suffix

    # Make the methods for this tool available where they are needed.
    for class_, method in (
            (SchLib.SchLib, '_load_sch_lib_'),
            (Part.Part, '_parse_lib_part_'),
            (Circuit.Circuit, '_gen_netlist_'),
            (Part.Part, '_gen_netlist_comp_'),
            (Net.Net, '_gen_netlist_net_'),
            (Circuit.Circuit, '_gen_xml_'),
            (Part.Part, '_gen_xml_comp_'),
            (Net.Net, '_gen_xml_net_'),
            ):
        try:
            setattr(class_, method+tool_name, getattr(mod, method))
        except AttributeError:
            pass  # No method implemented for this ECAD tool.



from skidl import Pin, Part, SchLib, SKIDL, TEMPLATE

SKIDL_lib_version = '0.0.1'

microchip_pic10mcu = SchLib(tool=SKIDL).add_parts(*[
        Part(name='PIC10(L)F320-I/MC',dest=TEMPLATE,tool=SKIDL,do_erc=True,aliases=['PIC10(L)F322-I/MC']),
        Part(name='PIC10(L)F320-I/OT',dest=TEMPLATE,tool=SKIDL,do_erc=True,aliases=['PIC10(L)F322-I/OT']),
        Part(name='PIC10(L)F320-I/P',dest=TEMPLATE,tool=SKIDL,do_erc=True,aliases=['PIC10(L)F322-I/P']),
        Part(name='PIC10F200-I/MC',dest=TEMPLATE,tool=SKIDL,keywords='FLASH 8-Bit CMOS Microcontroller',description='PIC10F202, 512W Flash, 24B SRAM, DFN8',ref_prefix='U',num_units=1,do_erc=True,aliases=['PIC10F202-I/MC'],pins=[
            Pin(num='2',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='3',name='T0CKI/FOSC4/GP2',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='ICSPCLK/GP1',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='ICSPDAT/GP0',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='Vpp/~MCLR~/GP3',do_erc=True)]),
        Part(name='PIC10F200-I/OT',dest=TEMPLATE,tool=SKIDL,keywords='FLASH 8-Bit CMOS Microcontroller',description='PIC10F202, 512W Flash, 24B SRAM, SOT-23-6',ref_prefix='U',num_units=1,do_erc=True,aliases=['PIC10F202-I/OT'],pins=[
            Pin(num='1',name='ICSPDAT/GP0',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='3',name='ICSPCLK/GP1',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='T0CKI/FOSC4/GP2',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='6',name='Vpp/~MCLR~/GP3',do_erc=True)]),
        Part(name='PIC10F200-I/P',dest=TEMPLATE,tool=SKIDL,keywords='FLASH 8-Bit CMOS Microcontroller',description='512W Flash, 24B SRAM, PDIP8',ref_prefix='U',num_units=1,do_erc=True,aliases=['PIC10F202-I/P'],pins=[
            Pin(num='2',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='3',name='T0CKI/FOSC4/GP2',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='ICSPCLK/GP1',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='ICSPDAT/GP0',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='Vpp/~MCLR~/GP3',do_erc=True)]),
        Part(name='PIC10F204-I/MC',dest=TEMPLATE,tool=SKIDL,keywords='FLASH 8-Bit CMOS Microcontroller',description='PIC10F206, 512W Flash, 24B SRAM, DFN8',ref_prefix='U',num_units=1,do_erc=True,aliases=['PIC10F206-I/MC'],pins=[
            Pin(num='2',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='3',name='T0CKI/COUT/FOSC4/GP2',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='ICSPCLK/CIN-/GP1',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='ICSPDAT/CIN+/GP0',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='Vpp/~MCLR~/GP3',do_erc=True)]),
        Part(name='PIC10F204-I/OT',dest=TEMPLATE,tool=SKIDL,keywords='FLASH 8-Bit CMOS Microcontroller',description='PIC10F206, 512W Flash, 24B SRAM, SOT-23-6',ref_prefix='U',num_units=1,do_erc=True,aliases=['PIC10F206-I/OT'],pins=[
            Pin(num='1',name='ICSPDAT/CIN+/GP0',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='3',name='ICSPCLK/CIN-/GP1',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='T0CKI/COUT/FOSC4/GP2',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='6',name='Vpp/~MCLR~/GP3',do_erc=True)]),
        Part(name='PIC10F204-I/P',dest=TEMPLATE,tool=SKIDL,keywords='FLASH 8-Bit CMOS Microcontroller',description='512W Flash, 24B SRAM, PDIP8',ref_prefix='U',num_units=1,do_erc=True,aliases=['PIC10F206-I/P'],pins=[
            Pin(num='2',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='3',name='T0CKI/COUT/FOSC4/GP2',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='ICSPCLK/CIN-/GP1',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='ICSPDAT/CIN+/GP0',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='Vpp/~MCLR~/GP3',do_erc=True)]),
        Part(name='PIC10F220-I/MC',dest=TEMPLATE,tool=SKIDL,keywords='FLASH 8-Bit CMOS Microcontroller',description='PIC10F222, 512W Flash, 24B SRAM, DFN8',ref_prefix='U',num_units=1,do_erc=True,aliases=['PIC10F222-I/MC'],pins=[
            Pin(num='2',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='3',name='T0CKI/FOSC4/GP2',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='ICSPCLK/AN1/GP1',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='ICSPDAT/AN0/GP0',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='Vpp/~MCLR~/GP3',do_erc=True)]),
        Part(name='PIC10F220-I/OT',dest=TEMPLATE,tool=SKIDL,keywords='FLASH 8-Bit CMOS Microcontroller',description='PIC10F222, 512W Flash, 24B SRAM, SOT-23-6',ref_prefix='U',num_units=1,do_erc=True,aliases=['PIC10F222-I/OT'],pins=[
            Pin(num='1',name='ICSPDAT/AN0/GP0',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='3',name='ICSPCLK/AN1/GP1',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='T0CKI/FOSC4/GP2',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='6',name='Vpp/~MCLR~/GP3',do_erc=True)]),
        Part(name='PIC10F220-I/P',dest=TEMPLATE,tool=SKIDL,keywords='FLASH 8-Bit CMOS Microcontroller',description='512W Flash, 24B SRAM, PDIP8',ref_prefix='U',num_units=1,do_erc=True,aliases=['PIC10F222-I/P'],pins=[
            Pin(num='2',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='3',name='T0CKI/FOSC4/GP2',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='ICSPCLK/AN1/GP1',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='ICSPDAT/AN0/GP0',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='Vpp/~MCLR~/GP3',do_erc=True)])])